@@ -1,9 +1,7 @@
 """ Citrix Netscaler Nitro API accessor """
 
 import urllib, urllib2
-from json import JSONEncoder
 from nsutil import *
-from nsresources import *
 
 __version__ = "0.0.2"
 
@@ -46,7 +44,7 @@ class NSNitro:
                 if not self.__initialized:
                         raise NSNitroError("Not initialized.")
 
-                payload = {"object":{"login":{"username":self.__user,"password":self.__password}}}
+                payload = {"object":json.dumps({"login":{"username":self.__user,"password":self.__password}})}
                 try:
                         nsresponse = self.post(payload)
                         if nsresponse.failed:
@@ -65,6 +63,7 @@ class NSNitro:
         def post(self, payload):
                 try:
                         payload_encoded = urllib.urlencode(payload)
+
                         req = urllib2.Request(self.__baseurl, payload_encoded, self.__postheaders)
                         response = urllib2.urlopen(req)
 
